==> better-admin-ui-vue-0.0.19.tgz: package/es/components/Cascader/Cascader.js <==
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it["return"] != null) it["return"](); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * @Date: 2020/11/23 6:32 下午
 * @Author: Fioanna
 * @Description: 级联选择器
 */
import ACascader from 'ant-design-vue/es/cascader';
import cascaderProps from './types';
import './style.less'; // 重新定义了options的数据类型

var ChangeCascader = {
  name: 'ChangeCascader',
  "extends": ACascader,
  props: {
    // 为了重写数据类型不报警告
    options: {
      type: Array,
      "default": function _default() {
        return [];
      }
    }
  }
};
export default {
  name: 'ECascader',
  props: cascaderProps,
  data: function data() {
    return {
      // 级联选择器默认选中的列表
      valueList: []
    };
  },
  computed: {
    // 列表解析的value和label
    fieldNames: function fieldNames() {
      return {
        value: this.valueName,
        label: this.labelName,
        children: 'children'
      };
    }
  },
  watch: {
    options: function options(newVal) {
      this._findDefaultSelect(newVal);
    },
    value: function value() {
      this._findDefaultSelect(this.options);
    }
  },
  created: function created() {
    this._findDefaultSelect(this.options);
  },
  methods: {
    /**
     * 找到默认值列表
     * @param options 可选列表
     * @private
     */
    _findDefaultSelect: function _findDefaultSelect(options) {
      if (options && options.length > 0 && this.value) {
        if (this.valueDivideNum) {
          var list = [];

          for (var i = this.valueDivideNum; i <= this.value.length; i = i + this.valueDivideNum) {
            list.push(this.value.substr(0, i));
          }

          this.valueList = list;
        } else {
          this.valueList = this._findDefaultValueList(options, this.value);
        }
      }
    },

    /**
     * 找到默认值列表
     * @param options 可选列表
     * @param defaultValue 选中值
     * @param valueList 找到的结果
     * @returns {*|*[]}
     * @private
     */
    _findDefaultValueList: function _findDefaultValueList(options, defaultValue) {
      var valueList = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];

      var _iterator = _createForOfIteratorHelper(options),
          _step;

      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var option = _step.value;
          var resList = [].concat(_toConsumableArray(valueList), [option[this.valueName]]);

          if (option.children) {
            // 判断是否有子节点，有的话就去找子节点
            var childrenRes = this._findDefaultValueList(option.children, defaultValue, resList);

            if (childrenRes) {
              return childrenRes;
            }
          } else if (option[this.valueName] === defaultValue) {
            // 没有子节点的话就判断跟协议返回的mcc是否相等，一致则返回对应列表
            return resList;
          }
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    },
    // 选择改变时
    _change: function _change(valueList, selectedOptions) {
      var _this = this;

      this.valueList = valueList;
      var value = valueList[valueList.length - 1];
      var label = selectedOptions.map(function (item) {
        return item[_this.labelName];
      }).join('/');
      this.$emit('change', value, label);
    }
  },
  render: function render() {
    var h = arguments[0];
    var _this$$props = this.$props,
        disabled = _this$$props.disabled,
        placeholder = _this$$props.placeholder,
        options = _this$$props.options;
    return h(ChangeCascader, {
      attrs: {
        disabled: disabled,
        placeholder: placeholder,
        options: options,
        fieldNames: this.fieldNames,
        value: this.$data.valueList
      },
      on: {
        "change": this._change
      }
    });
  }
};

==> better-admin-ui-vue-0.0.35.tgz: package/es/components/Cascader/Cascader.js <==
function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _createForOfIteratorHelper(o, allowArrayLike) { var it; if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) { if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") { if (it) o = it; var i = 0; var F = function F() {}; return { s: F, n: function n() { if (i >= o.length) return { done: true }; return { done: false, value: o[i++] }; }, e: function e(_e) { throw _e; }, f: F }; } throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); } var normalCompletion = true, didErr = false, err; return { s: function s() { it = o[Symbol.iterator](); }, n: function n() { var step = it.next(); normalCompletion = step.done; return step; }, e: function e(_e2) { didErr = true; err = _e2; }, f: function f() { try { if (!normalCompletion && it["return"] != null) it["return"](); } finally { if (didErr) throw err; } } }; }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

/**
 * @Date: 2020/11/23 6:32 下午
 * @Author: Fioanna
 * @Description: 级联选择器
 */
import ACascader from 'ant-design-vue/es/cascader';
import cascaderProps from './types';
import './style.less'; // 重新定义了options的数据类型

var ChangeCascader = {
  name: 'ChangeCascader',
  "extends": ACascader,
  props: {
    // 为了重写数据类型不报警告
    options: {
      type: Array,
      "default": function _default() {
        return [];
      }
    }
  }
};
export default {
  name: 'ECascader',
  props: cascaderProps,
  data: function data() {
    return {
      // 级联选择器默认选中的列表
      valueList: []
    };
  },
  computed: {
    // 列表解析的value和label
    fieldNames: function fieldNames() {
      return {
        value: this.valueName,
        label: this.labelName,
        children: 'children'
      };
    }
  },
  watch: {
    options: function options(newVal) {
      this._findDefaultSelect(newVal);
    },
    value: function value() {
      this._findDefaultSelect(this.options);
    }
  },
  created: function created() {
    this._findDefaultSelect(this.options);
  },
  methods: {
    /**
     * 找到默认值列表
     * @param options 可选列表
     * @private
     */
    _findDefaultSelect: function _findDefaultSelect(options) {
      if (options && options.length > 0 && this.value) {
        if (this.valueDivideNum) {
          var list = [];

          for (var i = this.valueDivideNum; i <= this.value.length; i = i + this.valueDivideNum) {
            list.push(this.value.substr(0, i));
          }

          this.valueList = list;
        } else {
          this.valueList = this._findDefaultValueList(options, this.value);
        }
      }
    },

    /**
     * 找到默认值列表
     * @param options 可选列表
     * @param defaultValue 选中值
     * @param valueList 找到的结果
     * @returns {*|*[]}
     * @private
     */
    _findDefaultValueList: function _findDefaultValueList(options, defaultValue) {
      var valueList = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : [];

      var _iterator = _createForOfIteratorHelper(options),
          _step;

      try {
        for (_iterator.s(); !(_step = _iterator.n()).done;) {
          var option = _step.value;
          var resList = [].concat(_toConsumableArray(valueList), [option[this.valueName]]);

          if (option.children) {
            // 判断是否有子节点，有的话就去找子节点
            var childrenRes = this._findDefaultValueList(option.children, defaultValue, resList);

            if (childrenRes) {
              return childrenRes;
            }
          } else if (option[this.valueName] === defaultValue) {
            // 没有子节点的话就判断跟协议返回的mcc是否相等，一致则返回对应列表
            return resList;
          }
        }
      } catch (err) {
        _iterator.e(err);
      } finally {
        _iterator.f();
      }
    },
    // 选择改变时
    _change: function _change(valueList, selectedOptions) {
      var _this = this;

      this.valueList = valueList;
      var value = valueList[valueList.length - 1];
      var label = selectedOptions.map(function (item) {
        return item[_this.labelName];
      }).join('/');
      this.$emit('change', value, label);
    }
  },
  render: function render() {
    var h = arguments[0];
    var _this$$props = this.$props,
        disabled = _this$$props.disabled,
        placeholder = _this$$props.placeholder,
        options = _this$$props.options,
        loadData = _this$$props.loadData;
    return h(ChangeCascader, {
      attrs: {
        disabled: disabled,
        placeholder: placeholder,
        options: options,
        fieldNames: this.fieldNames,
        value: this.$data.valueList,
        loadData: loadData
      },
      on: {
        "change": this._change
      }
    });
  }
};
